@@ -1,8 +1,10 @@
 from tuxrun.results import Results
+from tuxrun.tests import Test
 
 
 def test_returns_0_by_default():
-    results = Results()
+    results = Results([])
+    results.__data__ = {"lava": {}}
     assert results.ret() == 0
 
 
@@ -11,26 +13,37 @@ def gen_test(name, result, suite_name="mytestsuite"):
 
 
 def test_returns_0_with_no_failures():
-    results = Results()
+    t1 = Test(timeout=None)
+    t1.name = "mytestsuite"
+    results = Results([t1])
     results.parse(gen_test("test1", "pass"))
     results.parse(gen_test("test2", "pass"))
+    results.parse(gen_test("job", "pass", suite_name="lava"))
     assert results.ret() == 0
 
 
 def test_returns_1_on_failure():
-    results = Results()
-    results.parse(gen_test("test1", "pass"))
-    results.parse(gen_test("test2", "fail"))
+    results = Results([])
+    results.parse(gen_test("test1", "pass", suite_name="lava"))
+    results.parse(gen_test("test2", "fail", suite_name="lava"))
     assert results.ret() == 1
 
 
+def test_returns_2_on_missing_test():
+    t1 = Test(timeout=None)
+    t1.name = "mytestsuite"
+    results = Results([t1])
+    results.parse(gen_test("test1", "pass", suite_name="lava"))
+    assert results.ret() == 2
+
+
 def test_returns_invalid_logs():
-    results = Results()
+    results = Results([])
     results.parse("{")
     results.parse('{ "lvl": "results", "msg": {"case": "tux", "result": "pass"}}')
 
 
 def test_data():
-    results = Results()
+    results = Results([])
     results.parse(gen_test("test1", "pass"))
     assert results.data["mytestsuite"]["test1"]["result"] == "pass"
